==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/info/FormValueStyle.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FormValueStyle complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FormValueStyle"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="export" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="display" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="isDefault" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FormValueStyle")
public class FormValueStyle {

    @XmlAttribute(name = "export")
    protected String export;
    @XmlAttribute(name = "display")
    protected String display;
    @XmlAttribute(name = "isDefault")
    protected Boolean isDefault;

    /**
     * Gets the value of the export property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getExport() {
        if (export == null) {
            return "";
        } else {
            return export;
        }
    }

    /**
     * Sets the value of the export property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setExport(String value) {
        this.export = value;
    }

    public boolean isSetExport() {
        return (this.export!= null);
    }

    /**
     * Gets the value of the display property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDisplay() {
        if (display == null) {
            return "";
        } else {
            return display;
        }
    }

    /**
     * Sets the value of the display property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDisplay(String value) {
        this.display = value;
    }

    public boolean isSetDisplay() {
        return (this.display!= null);
    }

    /**
     * Gets the value of the isDefault property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIsDefault() {
        if (isDefault == null) {
            return false;
        } else {
            return isDefault;
        }
    }

    /**
     * Sets the value of the isDefault property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsDefault(boolean value) {
        this.isDefault = value;
    }

    public boolean isSetIsDefault() {
        return (this.isDefault!= null);
    }

    public void unsetIsDefault() {
        this.isDefault = null;
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/info/FormValueStyle.java <==

package net.webpdf.wsclient.schema.extraction.info;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns="http://schema.webpdf.de/1.0/extraction/info" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Selects parameters for the handling of a form fields values.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for FormValueStyle complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="FormValueStyle">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="export" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="display" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="isDefault" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FormValueStyle")
public class FormValueStyle {

    @XmlAttribute(name = "export")
    protected String export;
    @XmlAttribute(name = "display")
    protected String display;
    @XmlAttribute(name = "isDefault")
    protected Boolean isDefault;

    /**
     * Gets the value of the export property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getExport() {
        if (export == null) {
            return "";
        } else {
            return export;
        }
    }

    /**
     * Sets the value of the export property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setExport(String value) {
        this.export = value;
    }

    public boolean isSetExport() {
        return (this.export!= null);
    }

    /**
     * Gets the value of the display property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDisplay() {
        if (display == null) {
            return "";
        } else {
            return display;
        }
    }

    /**
     * Sets the value of the display property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDisplay(String value) {
        this.display = value;
    }

    public boolean isSetDisplay() {
        return (this.display!= null);
    }

    /**
     * Gets the value of the isDefault property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIsDefault() {
        if (isDefault == null) {
            return false;
        } else {
            return isDefault;
        }
    }

    /**
     * Sets the value of the isDefault property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsDefault(boolean value) {
        this.isDefault = value;
    }

    public boolean isSetIsDefault() {
        return (this.isDefault!= null);
    }

    public void unsetIsDefault() {
        this.isDefault = null;
    }

}
